package com.hzya.frame.grpU8.nxproof.glxmzl.dao.impl;



import com.baomidou.dynamic.datasource.annotation.DS;
import com.hzya.frame.basedao.dao.MybatisGenericDao;
import com.hzya.frame.grpU8.nxproof.glxmzl.dao.ISenderGlXmzlDao;
import com.hzya.frame.grpU8.nxproof.glxmzl.entity.SenderGlXmzlEntity;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * (GlXmzl)表数据库访问层
 *
 * @author makejava
 * @since 2024-06-20 10:02:38
 */
@Repository(value = "SenderGlXmzlDaoImpl")
public class SenderGlXmzlDaoImpl extends MybatisGenericDao<SenderGlXmzlEntity, String> implements ISenderGlXmzlDao {

    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public List<SenderGlXmzlEntity> querySenderGlXmzlEntity(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.queryByLike(senderGlXmzlEntity);
    }
    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public SenderGlXmzlEntity saveSenderGlXmzlEntity(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.save(senderGlXmzlEntity);
    }
    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public SenderGlXmzlEntity updateSenderGlXmzlEntity(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.update(senderGlXmzlEntity);
    }

    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public List<SenderGlXmzlEntity> queryGlXmzlHealthBureau(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.query(senderGlXmzlEntity);
    }

    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public SenderGlXmzlEntity saveGlXmzlHealthBureau(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.save(senderGlXmzlEntity);
    }

    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public SenderGlXmzlEntity updateGlXmzlHealthBureau(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.update(senderGlXmzlEntity);
    }

    @Override
    @DS("#senderGlXmzlEntity.dataSourceCode")
    public Integer deleteGlXmzlHealthBureau(SenderGlXmzlEntity senderGlXmzlEntity) {
        return super.delete("SenderGlXmzlEntity_delete_xmzl",senderGlXmzlEntity);
    }
}

